Crate grammers_tl_gen

Crate grammers_tl_gen 

This library is intended to be a build-time dependency, used to generate source code from parsed TL definitions.

Structs

Config
Configuration used by generate_rust_code.
Outputs
Writers to use as output for each generated module.

Functions

generate_rust_code
Generate the Rust code into the provided outputs for the given parsed definitions.